
import React from 'react';
import { Button } from '@/components/ui/button';

interface SidebarPanelProps {
  isOpen: boolean;
  content: any;
  onClose: () => void;
}

const SidebarPanel: React.FC<SidebarPanelProps> = ({ isOpen, content, onClose }) => {
  return (
    <div
      className={`fixed right-0 top-20 h-[calc(100vh-80px)] w-1/2 transform transition-transform duration-500 ease-in-out z-40 ${
        isOpen ? 'translate-x-0' : 'translate-x-full'
      }`}
    >
      <div className="h-full border-l border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/95 dark:bg-black/95">
        <div className="p-6 h-full overflow-y-auto">
          <div className="flex items-center justify-between mb-6">
            <h2 className="text-2xl font-bold text-gray-900 dark:text-white">
              {content?.title || 'Details'}
            </h2>
            <Button
              variant="ghost"
              onClick={onClose}
              className="w-10 h-10 rounded-full hover:bg-gray-100 dark:hover:bg-gray-800"
            >
              <svg className="w-5 h-5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
              </svg>
            </Button>
          </div>

          {content && (
            <div className="space-y-6">
              {content.component}
            </div>
          )}
        </div>
      </div>
    </div>
  );
};

export default SidebarPanel;
