
import React from 'react';
import { Card } from '@/components/ui/card';
import { Button } from '@/components/ui/button';

const HowToEarnContent = () => {
  return (
    <div className="space-y-8">
      <div className="text-center">
        <h2 className="text-3xl font-bold text-gray-900 dark:text-white mb-4">
          Monetize Your AI Creations
        </h2>
        <p className="text-xl text-gray-600 dark:text-gray-300">
          Turn your MCP servers into revenue-generating assets
        </p>
      </div>

      <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
        <Card className="p-6 border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/10 dark:bg-black/10">
          <div className="flex items-center mb-4">
            <div className="w-12 h-12 bg-gradient-to-br from-green-500 to-emerald-600 rounded-lg flex items-center justify-center mr-4">
              <svg className="w-6 h-6 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 8c-1.657 0-3 .895-3 2s1.343 2 3 2 3 .895 3 2-1.343 2-3 2m0-8c1.11 0 2.08.402 2.599 1M12 8V7m0 1v8m0 0v1m0-1c-1.11 0-2.08-.402-2.599-1" />
              </svg>
            </div>
            <h3 className="text-xl font-semibold text-gray-900 dark:text-white">
              Token-Based Revenue
            </h3>
          </div>
          <p className="text-gray-600 dark:text-gray-300 mb-4">
            Earn tokens every time users interact with your MCP servers. Set your own pricing and watch your revenue grow.
          </p>
          <div className="space-y-2">
            <div className="flex justify-between">
              <span className="text-sm text-gray-500">Per interaction</span>
              <span className="text-sm font-semibold text-green-600">0.01-0.50 tokens</span>
            </div>
            <div className="flex justify-between">
              <span className="text-sm text-gray-500">Monthly potential</span>
              <span className="text-sm font-semibold text-green-600">$100-$10,000+</span>
            </div>
          </div>
        </Card>

        <Card className="p-6 border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/10 dark:bg-black/10">
          <div className="flex items-center mb-4">
            <div className="w-12 h-12 bg-gradient-to-br from-blue-500 to-purple-600 rounded-lg flex items-center justify-center mr-4">
              <svg className="w-6 h-6 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M17 20h5v-2a3 3 0 00-5.356-1.857M17 20H7m10 0v-2c0-.656-.126-1.283-.356-1.857M7 20H2v-2a3 3 0 015.356-1.857M7 20v-2c0-.656.126-1.283.356-1.857m0 0a5.002 5.002 0 019.288 0M15 7a3 3 0 11-6 0 3 3 0 016 0zm6 3a2 2 0 11-4 0 2 2 0 014 0zM7 10a2 2 0 11-4 0 2 2 0 014 0z" />
              </svg>
            </div>
            <h3 className="text-xl font-semibold text-gray-900 dark:text-white">
              Series Subscriptions
            </h3>
          </div>
          <p className="text-gray-600 dark:text-gray-300 mb-4">
            Create premium series with exclusive content. Users subscribe for ongoing access to your specialized AI tools.
          </p>
          <div className="space-y-2">
            <div className="flex justify-between">
              <span className="text-sm text-gray-500">Monthly subscription</span>
              <span className="text-sm font-semibold text-blue-600">$5-$50/user</span>
            </div>
            <div className="flex justify-between">
              <span className="text-sm text-gray-500">Revenue share</span>
              <span className="text-sm font-semibold text-blue-600">70% creator</span>
            </div>
          </div>
        </Card>
      </div>

      <Card className="p-8 border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-gradient-to-br from-purple-50/50 to-pink-50/50 dark:from-purple-900/20 dark:to-pink-900/20">
        <h3 className="text-2xl font-bold text-gray-900 dark:text-white mb-6">
          Revenue Streams
        </h3>
        <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
          <div className="text-center">
            <div className="w-16 h-16 bg-gradient-to-br from-green-500 to-emerald-600 rounded-full flex items-center justify-center mx-auto mb-4">
              <span className="text-2xl">💰</span>
            </div>
            <h4 className="font-semibold text-gray-900 dark:text-white mb-2">Pay-per-Use</h4>
            <p className="text-sm text-gray-600 dark:text-gray-300">Users pay tokens for each interaction</p>
          </div>
          <div className="text-center">
            <div className="w-16 h-16 bg-gradient-to-br from-blue-500 to-purple-600 rounded-full flex items-center justify-center mx-auto mb-4">
              <span className="text-2xl">📱</span>
            </div>
            <h4 className="font-semibold text-gray-900 dark:text-white mb-2">App Licensing</h4>
            <p className="text-sm text-gray-600 dark:text-gray-300">License your MCPs to other developers</p>
          </div>
          <div className="text-center">
            <div className="w-16 h-16 bg-gradient-to-br from-orange-500 to-red-600 rounded-full flex items-center justify-center mx-auto mb-4">
              <span className="text-2xl">🎯</span>
            </div>
            <h4 className="font-semibold text-gray-900 dark:text-white mb-2">Premium Features</h4>
            <p className="text-sm text-gray-600 dark:text-gray-300">Offer advanced capabilities for higher fees</p>
          </div>
        </div>
      </Card>

      <div className="text-center">
        <Button className="bg-gradient-to-r from-green-500 to-emerald-600 hover:from-green-600 hover:to-emerald-700 text-white px-8 py-3 rounded-xl text-lg font-semibold shadow-lg">
          Start Earning Today
        </Button>
        <p className="text-sm text-gray-500 dark:text-gray-400 mt-2">
          No upfront costs • 70% revenue share • Instant payments
        </p>
      </div>
    </div>
  );
};

export default HowToEarnContent;
