
import React from 'react';
import { Card } from '@/components/ui/card';

const WhatIsMCPContent = () => {
  return (
    <div className="space-y-6">
      <div className="prose prose-lg dark:prose-invert max-w-none">
        <p className="text-lg text-gray-600 dark:text-gray-300 leading-relaxed">
          MCP (Model Context Protocol) is a revolutionary wrapper around LLM APIs that creates 
          a standardized interface for AI interactions. Think of it as the bridge between 
          traditional applications and the AI-first future.
        </p>
      </div>

      <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
        <Card className="p-6 border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/10 dark:bg-black/10">
          <div className="flex items-center mb-4">
            <div className="w-12 h-12 bg-gradient-to-br from-blue-500 to-purple-600 rounded-lg flex items-center justify-center mr-4">
              <svg className="w-6 h-6 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M8 9l3 3-3 3m5 0h3M5 20h14a2 2 0 002-2V6a2 2 0 00-2-2H5a2 2 0 00-2 2v12a2 2 0 002 2z" />
              </svg>
            </div>
            <h3 className="text-xl font-semibold text-gray-900 dark:text-white">
              Standardized Protocol
            </h3>
          </div>
          <p className="text-gray-600 dark:text-gray-300">
            Creates a universal language for AI agents to communicate with any application or service.
          </p>
        </Card>

        <Card className="p-6 border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/10 dark:bg-black/10">
          <div className="flex items-center mb-4">
            <div className="w-12 h-12 bg-gradient-to-br from-green-500 to-teal-600 rounded-lg flex items-center justify-center mr-4">
              <svg className="w-6 h-6 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M13 10V3L4 14h7v7l9-11h-7z" />
              </svg>
            </div>
            <h3 className="text-xl font-semibold text-gray-900 dark:text-white">
              Lightning Fast
            </h3>
          </div>
          <p className="text-gray-600 dark:text-gray-300">
            Optimized for real-time interactions with minimal latency and maximum efficiency.
          </p>
        </Card>
      </div>

      <Card className="p-8 border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-gradient-to-br from-blue-50/50 to-purple-50/50 dark:from-blue-900/20 dark:to-purple-900/20">
        <h3 className="text-2xl font-bold text-gray-900 dark:text-white mb-4">
          How MCP Works
        </h3>
        <div className="space-y-4">
          <div className="flex items-start space-x-4">
            <div className="w-8 h-8 bg-blue-500 rounded-full flex items-center justify-center text-white font-bold text-sm">
              1
            </div>
            <div>
              <h4 className="font-semibold text-gray-900 dark:text-white">Connect</h4>
              <p className="text-gray-600 dark:text-gray-300">Your application connects to MCP servers</p>
            </div>
          </div>
          <div className="flex items-start space-x-4">
            <div className="w-8 h-8 bg-purple-500 rounded-full flex items-center justify-center text-white font-bold text-sm">
              2
            </div>
            <div>
              <h4 className="font-semibold text-gray-900 dark:text-white">Process</h4>
              <p className="text-gray-600 dark:text-gray-300">MCP handles the communication and context</p>
            </div>
          </div>
          <div className="flex items-start space-x-4">
            <div className="w-8 h-8 bg-green-500 rounded-full flex items-center justify-center text-white font-bold text-sm">
              3
            </div>
            <div>
              <h4 className="font-semibold text-gray-900 dark:text-white">Deliver</h4>
              <p className="text-gray-600 dark:text-gray-300">Receive intelligent, contextual responses</p>
            </div>
          </div>
        </div>
      </Card>
    </div>
  );
};

export default WhatIsMCPContent;
