
import React from 'react';
import { Card } from '@/components/ui/card';

const WhoIsThisForContent = () => {
  const audiences = [
    {
      title: "Developers",
      description: "Build powerful MCP servers with full code control",
      icon: "💻",
      features: ["Full API access", "Custom integrations", "Advanced features", "Revenue sharing"],
      gradient: "from-blue-500 to-cyan-600"
    },
    {
      title: "Non-Coders",
      description: "Create amazing AI experiences without writing code",
      icon: "🎨",
      features: ["Visual builder", "Pre-built templates", "Drag & drop", "Instant deployment"],
      gradient: "from-purple-500 to-pink-600"
    },
    {
      title: "Creators",
      description: "Monetize your AI creations and build an audience",
      icon: "✨",
      features: ["Token economy", "Series monetization", "Community tools", "Analytics"],
      gradient: "from-green-500 to-emerald-600"
    }
  ];

  return (
    <div className="space-y-8">
      <div className="text-center">
        <h2 className="text-3xl font-bold text-gray-900 dark:text-white mb-4">
          Built for Everyone
        </h2>
        <p className="text-xl text-gray-600 dark:text-gray-300">
          Whether you code or not, MCP Platform empowers you to create AI-first applications
        </p>
      </div>

      <div className="grid grid-cols-1 gap-8">
        {audiences.map((audience, index) => (
          <Card 
            key={index}
            className="p-8 border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/10 dark:bg-black/10 hover:bg-white/20 dark:hover:bg-black/20 transition-all duration-300 hover:scale-105"
          >
            <div className="flex items-start space-x-6">
              <div className={`w-16 h-16 bg-gradient-to-br ${audience.gradient} rounded-2xl flex items-center justify-center text-2xl`}>
                {audience.icon}
              </div>
              <div className="flex-1">
                <h3 className="text-2xl font-bold text-gray-900 dark:text-white mb-2">
                  {audience.title}
                </h3>
                <p className="text-lg text-gray-600 dark:text-gray-300 mb-4">
                  {audience.description}
                </p>
                <div className="grid grid-cols-2 gap-2">
                  {audience.features.map((feature, featureIndex) => (
                    <div key={featureIndex} className="flex items-center space-x-2">
                      <div className="w-2 h-2 bg-green-500 rounded-full"></div>
                      <span className="text-sm text-gray-600 dark:text-gray-300">{feature}</span>
                    </div>
                  ))}
                </div>
              </div>
            </div>
          </Card>
        ))}
      </div>

      <Card className="p-8 border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-gradient-to-br from-yellow-50/50 to-orange-50/50 dark:from-yellow-900/20 dark:to-orange-900/20">
        <div className="text-center">
          <h3 className="text-2xl font-bold text-gray-900 dark:text-white mb-4">
            The AI-First Future
          </h3>
          <p className="text-lg text-gray-600 dark:text-gray-300 mb-6">
            Join thousands of creators building the next generation of AI-powered applications
          </p>
          <div className="flex justify-center space-x-8 text-center">
            <div>
              <div className="text-3xl font-bold text-blue-600 dark:text-blue-400">10K+</div>
              <div className="text-sm text-gray-600 dark:text-gray-300">Active Creators</div>
            </div>
            <div>
              <div className="text-3xl font-bold text-purple-600 dark:text-purple-400">50K+</div>
              <div className="text-sm text-gray-600 dark:text-gray-300">MCP Servers</div>
            </div>
            <div>
              <div className="text-3xl font-bold text-green-600 dark:text-green-400">$1M+</div>
              <div className="text-sm text-gray-600 dark:text-gray-300">Creator Earnings</div>
            </div>
          </div>
        </div>
      </Card>
    </div>
  );
};

export default WhoIsThisForContent;
