
import React, { useState } from 'react';
import Header from '../components/Header';
import ChatInterface from '../components/ChatInterface';
import SidebarPanel from '../components/SidebarPanel';
import { ThemeProvider } from '../contexts/ThemeContext';

const Index = () => {
  const [selectedPrompt, setSelectedPrompt] = useState<string | null>(null);
  const [sidebarContent, setSidebarContent] = useState<any>(null);

  const handlePromptSelect = (prompt: string, content: any) => {
    setSelectedPrompt(prompt);
    setSidebarContent(content);
  };

  const handleCloseSidebar = () => {
    setSelectedPrompt(null);
    setSidebarContent(null);
  };

  return (
    <ThemeProvider>
      <div className="min-h-screen bg-gradient-to-br from-white via-gray-50 to-gray-100 dark:from-black dark:via-gray-900 dark:to-gray-800 transition-all duration-500">
        <Header />
        
        <div className="flex h-[calc(100vh-80px)] relative">
          {/* Main Chat Interface */}
          <div className={`transition-all duration-500 ease-in-out ${
            selectedPrompt ? 'w-1/2' : 'w-full'
          }`}>
            <ChatInterface 
              onPromptSelect={handlePromptSelect}
              isExpanded={!selectedPrompt}
            />
          </div>

          {/* Sliding Sidebar Panel */}
          <SidebarPanel 
            isOpen={!!selectedPrompt}
            content={sidebarContent}
            onClose={handleCloseSidebar}
          />
        </div>

        {/* Subtle light leaks */}
        <div className="fixed inset-0 pointer-events-none overflow-hidden">
          <div className="absolute -top-1/2 -right-1/2 w-full h-full bg-gradient-radial from-blue-500/5 via-transparent to-transparent dark:from-blue-400/10"></div>
          <div className="absolute -bottom-1/2 -left-1/2 w-full h-full bg-gradient-radial from-purple-500/5 via-transparent to-transparent dark:from-purple-400/10"></div>
        </div>
      </div>
    </ThemeProvider>
  );
};

export default Index;
